#
# spec file for package orthanc-mysql
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orthanc-mysql
Summary:        Database plugin for Orthanc
License:        AGPL-3.0-or-later
Group:          Productivity/Databases/Tools
Version:        5.2
Release:        1.1
URL:            http://orthanc-server.com
Source0:        https://orthanc.uclouvain.be/downloads/sources/%{name}/OrthancMySQL-%{version}.tar.gz
Source1:        orthanc-mysql-readme.openSUSE
Source2:        mysql.json
BuildRequires:  cmake
BuildRequires:  e2fsprogs-devel
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  googletest-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_iostreams-devel >= 1.66
BuildRequires:  libboost_locale-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  libcurl-devel
BuildRequires:  libmysqld-devel
BuildRequires:  openssl-devel
BuildRequires:  orthanc-devel
BuildRequires:  orthanc-source
BuildRequires:  protobuf-devel
BuildRequires:  unzip
BuildRequires:  uuid-devel
BuildRequires:  zlib-devel

Requires:       mariadb
Requires:       orthanc

%description
MySQL/mariadb Database plugin for Orthanc, replaces SQLite database

%prep
%autosetup -n OrthancMySQL-%{version}

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
%cmake ../MySQL \
       -DALLOW_DOWNLOADS=ON \
       -DUSE_SYSTEM_GOOGLE_TEST=ON \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/OrthancFramework/Sources \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

%install

mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc

%cmake_install

# architecture dependet files should not be in /usr/share...
# create a directory
mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins

mv %{buildroot}%{_prefix}/share/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#Link from lib64 to orthanc plugin-directory, where it is expected
ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancMySQLIndex.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancMySQLIndex.so

ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancMySQLStorage.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancMySQLStorage.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/*.so

cp %{S:1} %{S:2} %{buildroot}%{_docdir}/orthanc/.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/orthanc
%{_docdir}/orthanc/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_prefix}/share/orthanc
%dir %{_prefix}/share/orthanc/plugins
%{_prefix}/share/orthanc/plugins/*.so*

%changelog
* Fri Jun  7 2024 Axel Braun <axel.braun@gmx.de>
- version 5.2
  * Fix check of Orthanc runtime version
  * Optimized resources deletion (https://discourse.orthanc-server.org/t/image-insert-are-too-slow-databse-performance-too-poor-when-using-mysql-mariadb/3820/19)
* Wed Mar 13 2024 Axel Braun <axel.braun@gmx.de>
- enable gcc13 for Leap 15.6
* Tue Jul 11 2023 Axel Braun <axel.braun@gmx.de>
- version 5.1
  * Optimization of LookupResources mainly used in tools/find, C-Find and QIDO-RS.
- version 5.0
  * Added support for labels
  * Compatibility with Orthanc SDK 1.12.0 (communications between the
    Orthanc core and the database plugin using Google Protocol Buffers)
  * Upgraded dependencies for static builds (notably on Windows and LSB):
  - openssl 3.1.0
* Thu Jul 22 2021 Axel Braun <axel.braun@gmx.de>
- version 4.3
  * Fix issue 200 (fields messed up in /changes route)
  * Added missing calls to OrthancPluginDatabaseSignalDeletedResource()
  * Fix serialization of large jobs
* Sun May  9 2021 Axel Braun <axel.braun@gmx.de>
- version 4.0 (no changelog)
* Tue Dec 22 2020 Axel Braun <axel.braun@gmx.de>
- readme.SUSE fixed and renamed
* Wed Dec 16 2020 Axel Braun <axel.braun@gmx.de>
- version 3.0
  * Report issue/solution and prevent the start of Orthanc if the MySQL user is
  not allowed to run the "CREATE TRIGGER" command (missing "SUPER" privilege)
  * Implementation of new extensions: LookupResourceAndParent and GetAllMetadata
  * Added an advisory lock to avoid race conditions during database setup
  * Added "MaximumConnectionRetries" & "ConnectionRetryInterval" to configure
  the retries when connecting to the DB at startup
  * Support of dynamic linking against the system-wide Orthanc framework library
  * Added support for TLS connections: 3 new options:
  - "EnableSsl" (false by default)
  - "SslVerifyServerCertificates" (true by default - inactive if EnableSsl if false)
  - "SslCACertificates" (default value is "HttpsCACertificates" from global
    Orthanc configuration)
  * Uses Orthanc Framework 1.8.1
* Thu Oct 22 2020 Axel Braun <axel.braun@gmx.de>
- switch build system to orthanc-framework (static)
* Sat Jan 25 2020 Axel Braun <axel.braun@gmx.de>
- OrthancMySQL V2.0 - initial build on OBS
